@@ -1,4 +1,5 @@
 from .core import SQLFocus, logger
+from .helpers import all2string
 
 INSERT_INTO_SQL = "INSERT INTO {name} VALUES ({values});"
 CREATE_SQL = "CREATE TABLE {exists}{name} ({vars});"
@@ -66,11 +67,3 @@ class SQLTable(SQLTableBase):
         self.name = name
         self.conn = conn
         self.quote = quote
-
-
-def all2string(args, q='"'):
-    if args.__class__ == list or args.__class__ == tuple:
-        return [str(_) if _.__class__ != str else f"{q}{_}{q}" for _ in args]
-    else:
-        return [f"{_}={args[_]}" if args[_].__class__ != str
-                else f"{_}={q}{args[_]}{q}" for _ in args]
